@@ -205,7 +205,8 @@ bool read_multi_label_template
     const bool ignore_zero_valued,
     const bool sort_indices,
     const bool text_is_base1,
-    const bool assume_no_qid
+    const bool assume_no_qid,
+    const bool assume_trailing_ws
 )
 {
     if (input_file.fail())
@@ -513,7 +514,8 @@ bool read_multi_label_template
     const bool ignore_zero_valued,
     const bool sort_indices,
     const bool text_is_base1,
-    const bool assume_no_qid
+    const bool assume_no_qid,
+    const bool assume_trailing_ws
 )
 {
     if (input_file == NULL)
@@ -807,16 +809,45 @@ bool read_multi_label_template
                 qid.push_back(curr_col);
         }
 
-        while ((n_matched = fscanf(input_file, parse_code_features, &curr_col, &curr_val)) == 2)
+        n_matched = 0;
+        if (assume_trailing_ws)
         {
-            if (!ignore_zero_valued || curr_val)
+            while ((n_matched = fscanf(input_file, parse_code_features, &curr_col, &curr_val)) == 2)
             {
-                indices.push_back(curr_col);
-                values.push_back(curr_val);
+                if (!ignore_zero_valued || curr_val)
+                {
+                    indices.push_back(curr_col);
+                    values.push_back(curr_val);
+                }
+                
+                return_to = ftell_(input_file);
+                do { next_char = fgetc(input_file); }
+                while (next_char != EOF && isspace(next_char) && (char)next_char != '\n');
+                if (next_char == EOF || (char)next_char == '\n' || (char)next_char == '#')
+                    goto next_line;
+                else
+                    fseek_(input_file, return_to, SEEK_SET);
+            }
+            if (n_matched == 1) {
+                fseek_(input_file, return_to, SEEK_SET);
+                goto next_line;
+            }
+        }
+
+        else
+        {
+            while ((n_matched = fscanf(input_file, parse_code_features, &curr_col, &curr_val)) == 2)
+            {
+                if (!ignore_zero_valued || curr_val)
+                {
+                    indices.push_back(curr_col);
+                    values.push_back(curr_val);
+                }
+                
+                next_char = fgetc(input_file);
+                if ((char)next_char == '\n' || (char)next_char == '\r' || !isspace((char)next_char))
+                    break;
             }
-            next_char = fgetc(input_file);
-            if ((char)next_char == '\n' || (char)next_char == '\r' || !isspace((char)next_char))
-                break;
         }
 
 
@@ -841,6 +872,11 @@ bool read_multi_label_template
         }
     }
 
+    if (!feof(input_file) && ferror(input_file))
+    {
+        print_errno();
+        return false;
+    }
 
     if (text_is_base1) {
         subtract_one_from_vec(indices);
@@ -879,7 +915,8 @@ bool read_single_label_template
     const bool ignore_zero_valued,
     const bool sort_indices,
     const bool text_is_base1,
-    const bool assume_no_qid
+    const bool assume_no_qid,
+    const bool assume_trailing_ws
 )
 {
     if (input_file.fail())
@@ -1246,7 +1283,8 @@ bool read_single_label_template
     const bool ignore_zero_valued,
     const bool sort_indices,
     const bool text_is_base1,
-    const bool assume_no_qid
+    const bool assume_no_qid,
+    const bool assume_trailing_ws
 )
 {
     if (input_file == NULL)
@@ -1611,18 +1649,45 @@ bool read_single_label_template
                 qid.push_back(curr_col);
         }
 
-        while ((n_matched = fscanf(input_file, parse_code_features, &curr_col, &curr_val)) == 2)
+        if (assume_trailing_ws)
         {
-            if (!ignore_zero_valued || curr_val)
+            while ((n_matched = fscanf(input_file, parse_code_features, &curr_col, &curr_val)) == 2)
             {
-                indices.push_back(curr_col);
-                values.push_back(curr_val);
+                if (!ignore_zero_valued || curr_val)
+                {
+                    indices.push_back(curr_col);
+                    values.push_back(curr_val);
+                }
+                
+                return_to = ftell_(input_file);
+                do { next_char = fgetc(input_file); }
+                while (next_char != EOF && isspace(next_char) && (char)next_char != '\n');
+                if (next_char == EOF || (char)next_char == '\n' || (char)next_char == '#')
+                    goto next_line;
+                else
+                    fseek_(input_file, return_to, SEEK_SET);
+            }
+                if (n_matched == 1) {
+                fseek_(input_file, return_to, SEEK_SET);
+                goto next_line;
             }
-            next_char = fgetc(input_file);
-            if ((char)next_char == '\n' || (char)next_char == '\r' || !isspace((char)next_char))
-                break;
         }
 
+        else
+        {
+             while ((n_matched = fscanf(input_file, parse_code_features, &curr_col, &curr_val)) == 2)
+            {
+                if (!ignore_zero_valued || curr_val)
+                {
+                    indices.push_back(curr_col);
+                    values.push_back(curr_val);
+                }
+                
+                next_char = fgetc(input_file);
+                if ((char)next_char == '\n' || (char)next_char == '\r' || !isspace((char)next_char))
+                    break;
+                }
+        }
 
         next_line:
         indptr.push_back(indices.size());
@@ -1645,6 +1710,12 @@ bool read_single_label_template
         }
     }
 
+    if (!feof(input_file) && ferror(input_file))
+    {
+        print_errno();
+        return false;
+    }
+
     if (text_is_base1)
         subtract_one_from_vec(indices);
 
